Forked as upstream did not make a release in quite a while, I hope to kill this fork off in the future.

I recommend doing `import lynxpresence as pypresence` to keep compatibility and allow easy switching in case upstream picks up again.

> A Discord Rich Presence Client in Python? Looks like you've come to the right place.

![PyPI](https://img.shields.io/pypi/v/lynxpresence.svg?style=for-the-badge)

----------

# Installation

Install pypresence with `pip`, for the latest development version:

```shell
pip install https://github.com/C0rn3j/lynxpresence/archive/master.zip
```

For the latest stable version:

```shell
pip install lynxpresence
```

----------

# Documentation

> [!Note]
> You need an **authorized app** to do anything besides rich presence!

####  [pypresence Documentation](https://qwertyquerty.github.io/pypresence/html/index.html)
####  [Discord Rich Presence Documentation](https://discord.com/developers/docs/rich-presence/how-to)
####  [Discord RPC Documentation](https://discord.com/developers/docs/topics/rpc)
####  [pyresence Discord Support Server](https://discord.gg/JF3kg77)
####  [Discord API Support Server](https://discord.gg/discord-api)

----------

# Examples

Examples can be found in the [examples](https://github.com/C0rn3j/pypresence/tree/master/examples) directory, and you can contribute your own examples if you wish, just read [examples.md](https://github.com/C0rn3j/pypresence/blob/master/examples/examples.md)!

----------

# Development

Want to contribute? Check out the **[Development Guide](DEVELOPMENT.md)** for setup instructions, testing, code quality tools, and contribution guidelines.
